@@ -60,11 +60,15 @@ class WhisperFlask(Flask):
         )
         self.static_folder = os.path.join(self.instance_path, '_static')
         # app misc config
-        self.secret_key = secrets.token_hex(32)
-        self.use_x_sendfile = True
+        self.config.update({
+            'SECRET_KEY': secrets.token_hex(32),
+            'USE_X_SENDFILE': True,
+            'SESSION_REFRESH_EACH_REQUEST': True,
+            'SESSION_COOKIE_SAMESITE': 'Lax',
+            'SESSION_COOKIE_SECURE': True,
+        })
         self.url_map.converters['slug'] = WhisperFlask.SlugConverter
         self.jinja_options['autoescape'] = False  # be careful
-        self.config['SESSION_REFRESH_EACH_REQUEST'] = True
         # app global objects
         self.c = Config()
         self.e = EventManager()
@@ -101,11 +105,10 @@ with app.app_context():
     db.init_db()
 
     # execute user config
-    with open(
-        current_app.instance_resource('config.py'),
-        'r',
-        encoding='utf-8',
-    ) as f:
+    config = current_app.instance_resource('config.py')
+    if not os.path.isfile(config):
+        raise FileNotFoundError(f'Config file `{config}` not found!')
+    with open(config, 'r', encoding='utf-8') as f:
         # pylint: disable=exec-used
         exec(compile(
             f.read(),
@@ -117,7 +120,7 @@ with app.app_context():
     app.main = app.p['main'] = app.p.get(app.c.core.main)  # type: ignore
     if not isinstance(app.p['main'], MainProvider):
         raise TypeError(
-            f'MainProvider not found at {app.c.core.main}.config.provider'
+            f'MainProvider not found at `{app.c.core.main}.config.provider`'
         )
 
     # finished starting
