@@ -2,14 +2,16 @@
 This module dispatches pages to the main provider plugin
 """
 import typing as t
-from flask import Blueprint, request, abort, send_from_directory
+import jinja2
+from flask import Blueprint, request, abort, send_from_directory, \
+                  render_template
 from flask.typing import ResponseReturnValue
 
 from . import current_app
 from .post import get_post
 from .provider import BaseProvider
 
-__all__: list[str] = []
+__all__ = ['template']
 
 bp = Blueprint('core', __name__)
 
@@ -23,6 +25,25 @@ def inject_config() -> dict[str, t.Any]:
     }
 
 
+def template(
+    plugin: str,
+    file: str,
+    plugin_template_dir: str = 'template',
+    enforce_template_dir: t.Union[str, list[str]] = '',
+    **kwargs: t.Any
+) -> str:
+    """Render from package specified template directory"""
+    old_loader = current_app.jinja_env.loader
+    try:
+        current_app.jinja_env.loader = jinja2.FileSystemLoader(
+            enforce_template_dir
+            or current_app.app_resource(plugin, plugin_template_dir)
+        )
+        return render_template(file, **kwargs)
+    finally:
+        current_app.jinja_env.loader = old_loader
+
+
 @bp.route('/<slug:slug>/', endpoint='post', defaults={'path': ''})
 @bp.route('/<slug:slug>/<path:path>', endpoint='post_resource')
 def post_page(slug: str, path: str) -> ResponseReturnValue:
@@ -32,21 +53,17 @@ def post_page(slug: str, path: str) -> ResponseReturnValue:
     # post not found
     if not p:
         # may use hook
-        evt = current_app.e('core:post_not_found', {'slug': slug})
-        if 'return' in evt:
-            return evt['retrun']  # type: ignore
+        current_app.e('core:post_not_found', {'slug': slug})
         abort(404)
     # provider not found
     if p.provide not in current_app.p:
         # may use hook
         evt = current_app.e('core:provider_not_found', {'slug': slug})
-        if 'return' in evt:
-            return evt['return']  # type: ignore
         # may use dynamic provider
         if 'provider' in evt and isinstance(evt['provider'], BaseProvider):
             return evt['provider'].render(p, path)
         current_app.logger.warning(f'provider {p.provide} not found')
-        raise NameError(f'provider {p.provide} not found')
+        raise NameError(f'provider `{p.provide}` not found')
     # use the provider specified
     return current_app.p[p.provide].render(p, path)
 
@@ -63,9 +80,7 @@ def list_page(tag: t.Optional[str]) -> ResponseReturnValue:
 @bp.route('/static/<path:path>', endpoint='static')
 def static(path: str) -> ResponseReturnValue:
     """Search user static files"""
-    evt = current_app.e('core:static', {'path': path})
-    if 'return' in evt:
-        return evt['return']  # type: ignore
+    current_app.e('core:static', {'path': path})
     if not current_app.static_folder:
         abort(404)
     return send_from_directory(current_app.static_folder, path)
