@@ -5,7 +5,7 @@ import typing as t
 
 from . import current_app
 
-__all__ = ['EventManager', 'AnyDict', 'EventHandler']
+__all__ = ['EventManager', 'AnyDict', 'EventHandler', 'event_handler']
 
 AnyDict = dict[t.Any, t.Any]
 EventHandler = t.Callable[[AnyDict], AnyDict]
@@ -28,11 +28,21 @@ class EventManager:
         """Invoke a event by name, call functions with args specified"""
         if arg is None:
             arg = {}
+        if event.startswith('main:'):
+            event = event.replace('main:', f'{current_app.c.core.main}:')
         for callback in self.registry.get(event, []):
             ret = callback(arg)
             if not isinstance(ret, dict):
-                raise TypeError('event handler must return a dict')
+                raise TypeError('event handler must return a `dict`')
             arg = ret
             if arg.pop('_stop', False):
                 break
         return arg
+
+
+def event_handler(event: str) -> t.Callable[[EventHandler], EventHandler]:
+    """Register decorated function as event handler"""
+    def decorator(f: EventHandler) -> EventHandler:
+        current_app.e.register(event, f)
+        return f
+    return decorator
