@@ -33,8 +33,6 @@ class Post:
     ) -> None:
         """Check slug format and init object"""
         # pylint: disable=too-many-arguments
-        if re.match(r'^[a-z0-9]+(-[a-z0-9]+)*$', slug) is None:
-            raise ValueError('slug must be dash-joined [a-z0-9]')
         self.slug = slug
         self._orig_slug = slug
         self.provide = provide
@@ -53,7 +51,19 @@ class Post:
         current_app.e('core:load_post', {'post': self})
 
     @property
-    def tag(self) -> set[str]:
+    def slug(self) -> str:
+        """Slug checker"""
+        return self._slug
+
+    @slug.setter
+    def slug(self, val: str) -> None:
+        """Slug checker"""
+        if re.match(r'^[a-z0-9]+(-[a-z0-9]+)*$', val) is None:
+            raise ValueError('slug must be dash-joined [a-z0-9]')
+        self._slug = val
+
+    @property
+    def tag(self) -> list[str]:
         """Lazy load tags of a post"""
         if self._tag is None:
             cur = current_app.db.execute(
@@ -63,7 +73,17 @@ class Post:
             self._tag = {row['tag'] for row in cur}
             self._orig_tag = self._tag.copy()
             current_app.e('core:load_post_tag', {'post': self})
-        return self._tag
+        return sorted(self._tag)
+
+    @tag.setter
+    def tag(self, tags: list[str]) -> None:
+        if not isinstance(tags, list):
+            raise TypeError(f'tags must be `list`, not `{type(tags)}`')
+        for tag_ in tags:
+            if not isinstance(tag_, str):
+                raise TypeError(f'tag must be `str`, not `{type(tag_)}`')
+        self._tag = set(tags)
+        self._tag.difference_update({''})
 
     @property
     def meta(self) -> dict[str, str]:
@@ -78,8 +98,20 @@ class Post:
             current_app.e('core:load_post_meta', {'post': self})
         return self._meta
 
+    @meta.setter
+    def meta(self, metas: dict[str, str]) -> None:
+        if not isinstance(metas, dict):
+            raise TypeError(f'metas must be `dict`, not `{type(metas)}`')
+        for k, v in metas.items():
+            if not isinstance(k, str):
+                raise TypeError(f'meta key must be `str`, not `{type(k)}`')
+            if not isinstance(v, str):
+                raise TypeError(f'meta value must be `str`, not `{type(v)}`')
+        metas.pop('', None)
+        self._meta = metas.copy()
+
     @property
-    def file(self) -> list[str]:
+    def files(self) -> list[str]:
         """Scan upload dir to list files associated with this post"""
         path = current_app.instance_resource(self._orig_slug)
         if not os.path.isdir(path):
@@ -94,6 +126,8 @@ class Post:
         """Save attributes into database, save new slug, tags and metadatas if necessary"""
         current_app.e('core:save_post', {'post': self})
         self.provide = self.provide or 'main'
+        if not self.creation:
+            self.creation = int(time.time())
         self.modified = int(time.time())
         current_app.db.execute(
             'REPLACE INTO post VALUES (?,?,?,?,?,?,?,?,?)',
@@ -172,16 +206,16 @@ def get_post(slug: str, show_private: bool = False) -> t.Optional[Post]:
 def get_posts(
     page: int,
     page_size: int,
-    tag: t.Optional[str],
-    indexed: t.Optional[bool],
-    public: t.Optional[bool],
-    provider: t.Optional[str],
-    like: t.Optional[str],
+    tag: t.Optional[str] = None,
+    indexed: t.Optional[bool] = None,
+    public: t.Optional[bool] = None,
+    provider: t.Optional[str] = None,
+    like: t.Optional[str] = None,
 ) -> tuple[list[Post], int]:
     """Return a list of Post with filtering and pagination"""
     # pylint: disable=too-many-arguments
     tag = current_app.e('core:get_posts', {'tag': tag}).get('tag', tag)
-    if tag:
+    if tag is not None:
         cond_sql = ' JOIN tag ON post.slug = tag.post WHERE tag.tag = :tag'
     else:
         cond_sql = ' WHERE 1'
