@@ -8,20 +8,20 @@ CREATE TABLE post (
   title TEXT NOT NULL DEFAULT '',
   excerpt TEXT NOT NULL DEFAULT '',
   content TEXT NOT NULL DEFAULT ''
-) STRICT;
+);
 
 CREATE TABLE tag (
   post TEXT NOT NULL REFERENCES post(slug) ON UPDATE CASCADE ON DELETE CASCADE,
   tag TEXT NOT NULL,
   PRIMARY KEY (post, tag) ON CONFLICT IGNORE
-) STRICT;
+);
 
 CREATE TABLE meta (
   post TEXT NOT NULL REFERENCES post(slug) ON UPDATE CASCADE ON DELETE CASCADE,
   k TEXT NOT NULL,
   v TEXT NOT NULL,
   PRIMARY KEY (post, k) ON CONFLICT REPLACE
-) STRICT;
+);
 
 CREATE INDEX idx_provide ON post(provide);
 CREATE INDEX idx_public ON post(public);
